<?php 

//Setup Theme
function ow_axio_theme_setup() {

    // Function for Title
    function ow_axio_theme_wp_title( $title, $sep ) {
        global $paged, $page;

        if ( is_feed() )
            return $title;

        // Add the site name.
        $title .= get_bloginfo( 'name' );

        // Add the site description for the home/front page.
        $site_description = get_bloginfo( 'description', 'display' );
        if ( $site_description && ( is_home() || is_front_page() ) )
            $title = "$title $sep $site_description";

        // Add a page number if necessary.
        if ( $paged >= 2 || $page >= 2 )
            $title = "$title $sep " . sprintf( __( 'Page %s', 'ow_axio_theme' ), max( $paged, $page ) );

        return $title;
    }
    add_filter( 'wp_title', 'ow_axio_theme_wp_title', 10, 2 );

    //Content-width
    $defaults = array(
        'post'       => '500',
        'page'       => '500',
        'attachment' => '650',
        'artist'     => '300',
        'movie'      => '400'
    );
    add_theme_support( 'content-width', $defaults );

    if ( ! isset( $content_width ) ) $content_width = 900;

	load_theme_textdomain( 'ow_axio_theme', get_template_directory() . '/languages' );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Enable support for Post Thumbnails, and declare two sizes.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 672, 372, true );
	add_image_size( 'ow_axio_theme-full-width', 1038, 576, true );
    add_image_size( 'thumbnail-blog', 940, 200, true);
    add_image_size( 'homepage', 100, 400, true);
    add_image_size( 'thumb-clients-wg', 9999, 90, array( 'left', 'top' ) );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main-menu'   => __( 'Main ', 'ow_axio_theme' ),
       ) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
       ) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'audio', 'quote', 'link',
       ) );

	// Add support for featured content.
	add_theme_support( 'featured-content', array(
		'featured_content_filter' => 'ow_axio_theme_get_featured_posts',
		'max_posts' => 6,
       ) );

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );


    // Register Styles
    function ow_styles() {

        wp_register_style( 'style', get_template_directory_uri().'/css/style.css', '1.1', 'all' );
        wp_register_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css', '1.1', 'all' );
        wp_register_style( 'animated-progress', get_template_directory_uri().'/css/animated-progress.css', '1.1', 'all' );
        wp_register_style( 'font-awesome', get_template_directory_uri().'/fonts/font-awesome/css/font-awesome.min.css', '1.1', 'all' );

        wp_enqueue_style('font-awesome');
        wp_enqueue_style( 'bootstrap' );
        wp_enqueue_style( 'animated-progress' );
        wp_enqueue_style( 'style' );
    }

    // Hook into the 'wp_enqueue_scripts' action
    //add_action( 'wp_head', 'ow_styles' );

    add_action('wp_enqueue_scripts', 'ow_styles');


    // Sidebars for Axio Theme 

    function axio_widgets_inits() {
        register_sidebar( array( 'id' => 'blog', 'name' => 'Blog') );
        register_sidebar( array( 'id' => 'contact', 'name' => 'Contact') );
        register_sidebar( array( 'id' => 'header', 'name' => 'Header') );
        register_sidebar( array( 'id' => 'footer-1', 'name' => 'Footer Column 1') );
        register_sidebar( array( 'id' => 'footer-2', 'name' => 'Footer Column 2') );
        register_sidebar( array( 'id' => 'footer-3', 'name' => 'Footer Column 3') );
    }
    add_action( 'widgets_init', 'axio_widgets_inits' );
    


    /*------------ ADMIN PANEL INIT -------*/
    include(TEMPLATEPATH . '/admin-folder/admin/admin-init.php');



    /*------------ FUNCTIONS --------------*/

    function wpbootstrap_scripts_with_jquery()
    {
    	// Register the script like this for a theme:
    	wp_register_script( 'custom-script', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ) );
    	// For either a plugin or a theme, you can then enqueue the script:
    	wp_enqueue_script( 'custom-script' );
    }
    add_action( 'wp_enqueue_scripts', 'wpbootstrap_scripts_with_jquery' );



    class BootstrapNavMenuWalker extends Walker_Nav_Menu {


        function start_lvl( &$output, $depth = 0, $args = array() ) {

            $indent = str_repeat( "\t", $depth );
            $submenu = ($depth > 0) ? ' sub-menu' : '';
            $output	.= "\n$indent<ul class=\"dropdown-menu$submenu depth_$depth\">\n";

        }

        function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {


            $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

            $li_attributes = '';
            $class_names = $value = '';

            $classes = empty( $item->classes ) ? array() : (array) $item->classes;
    // managing divider: add divider class to an element to get a divider before it.
            $divider_class_position = array_search('divider', $classes);
            if($divider_class_position !== false){
                $output .= "<li class=\"divider\"></li>\n";
                unset($classes[$divider_class_position]);
            }
            $classes[] = ($args->has_children) ? 'dropdown' : '';
            $classes[] = ($item->current || $item->current_item_ancestor) ? 'active' : '';
            $classes[] = 'menu-item-' . $item->ID;
            if($depth && $args->has_children){
                $classes[] = 'dropdown-submenu';
            }


            $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
            $class_names = ' class="' . esc_attr( $class_names ) . '"';

            $id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
            $id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';

            $output .= $indent . '<li' . $id . $value . $class_names . $li_attributes . '>';

            $attributes = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) .'"' : '';
            $attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
            $attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
            $attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';
            $attributes .= ($args->has_children) ? ' class="dropdown-toggle" data-toggle="dropdown"' : '';

            $item_output = $args->before;
            $item_output .= '<a'. $attributes .'>';
            $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
            $item_output .= ($depth == 0 && $args->has_children) ? ' <b class="caret"></b></a>' : '</a>';
            $item_output .= $args->after;


            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
        }

        function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {
    //v($element);
            if ( !$element )
                return;

            $id_field = $this->db_fields['id'];

    //display this element
            if ( is_array( $args[0] ) )
                $args[0]['has_children'] = ! empty( $children_elements[$element->$id_field] );
            else if ( is_object( $args[0] ) )
                $args[0]->has_children = ! empty( $children_elements[$element->$id_field] );
            $cb_args = array_merge( array(&$output, $element, $depth), $args);
            call_user_func_array(array(&$this, 'start_el'), $cb_args);

            $id = $element->$id_field;

    // descend only when the depth is right and there are childrens for this element
            if ( ($max_depth == 0 || $max_depth > $depth+1 ) && isset( $children_elements[$id]) ) {

                foreach( $children_elements[ $id ] as $child ){

                    if ( !isset($newlevel) ) {
                        $newlevel = true;
    //start the child delimiter
                        $cb_args = array_merge( array(&$output, $depth), $args);
                        call_user_func_array(array(&$this, 'start_lvl'), $cb_args);
                    }
                    $this->display_element( $child, $children_elements, $max_depth, $depth + 1, $args, $output );
                }
                unset( $children_elements[ $id ] );
            }

            if ( isset($newlevel) && $newlevel ){
    //end the child delimiter
                $cb_args = array_merge( array(&$output, $depth), $args);
                call_user_func_array(array(&$this, 'end_lvl'), $cb_args);
            }

    //end this element
            $cb_args = array_merge( array(&$output, $element, $depth), $args);
            call_user_func_array(array(&$this, 'end_el'), $cb_args);

        }

    } 

         function ow_abovemenu() {
            global $ow_axio_theme;

            if ($ow_axio_theme['opt-abovemenu'] == true ) {
                ?>
                    <!-- Above menu -->
                    <section class="abovemenu">

                        <div class="container">
                            <div class="row clearfix">
                                <div class="col-md-12 column">
                                    <!-- Contact Info -->
                                    <div class="contact-info">
                                        <?php 
                                            ow_contact_info('phone');
                                            ow_contact_info('email');
                                            ow_contact_info('address');
                                        ?>
                                    </div>
                                    <!-- Social Icons-->
                                    <ul class="social-icons">
                                        <?php
                                            ow_social_icons('skype'); 
                                            ow_social_icons('facebook');
                                            ow_social_icons('twitter');
                                            ow_social_icons('googleplus');
                                            ow_social_icons('linkedin');
                                            ow_social_icons('youtube');
                                            ow_social_icons('vimeo');
                                            ow_social_icons('pinterest');
                                        ?>
                                    </ul>
                                    <!-- /Social Icons-->
                                </div>
                            </div>      
                        </div>  

                    </section>  
                    <!-- /Above menu -->

                <?php
                } else {
                echo '';
            }
         }

    // Function Google Analytics

        function ow_analytics() {
            global $ow_axio_theme;

            $tracking_code = $ow_axio_theme['opt-analytics'];

            if ( $tracking_code == false ) {
                echo '';
            } else { ?>

                <script>
                  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
                  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
                  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
                  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

                  ga('create', '<?php echo $tracking_code; ?>', 'auto');
                  ga('send', 'pageview');

                </script>
            
            <?php
            }
        }


    // This theme uses wp_nav_menu() in two locations.
        register_nav_menus( array(
        	'primary'   => __( 'Top primary menu', 'ow_axio_theme' ),
        ) );


    // Include Primary color style
    include(TEMPLATEPATH . '/colors.php'); 


    // The Breadcrumbs

    function the_breadcrumb() {
        global $post;
        echo '<ol class="breadcrumb">';
        if (!is_home()) {
            echo '<li><a href="';
            echo home_url();
            echo '">';
            echo 'Home';
            echo '</a></li>';
            if (is_category() || is_single()) {
                echo '<li>';
                the_category(' </li><li> ');
                if (is_single()) {
                    echo '</li><li>';
                    the_title();
                    echo '</li>';
                }
            } elseif (is_page()) {
                if($post->post_parent){
                    $anc = get_post_ancestors( $post->ID );
                    $title = get_the_title();
                    foreach ( $anc as $ancestor ) {
                        $output = '<li><a href="'.get_permalink($ancestor).'" title="'.get_the_title($ancestor).'">'.get_the_title($ancestor).'</a></li>';
                    }
                    echo $output;
                    echo '<strong title="'.$title.'"> '.$title.'</strong>';
                } else {
                    echo '<li><strong> '.get_the_title().'</strong></li>';
                }
            }
        }
        elseif (is_tag()) {single_tag_title();}
        elseif (is_day()) {echo"<li>Archive for "; the_time('F jS, Y'); echo'</li>';}
        elseif (is_month()) {echo"<li>Archive for "; the_time('F, Y'); echo'</li>';}
        elseif (is_year()) {echo"<li>Archive for "; the_time('Y'); echo'</li>';}
        elseif (is_author()) {echo"<li>Author Archive"; echo'</li>';}
        elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {echo "<li>Blog Archives"; echo'</li>';}
        elseif (is_search()) {echo"<li>Search Results"; echo'</li>';}
        echo '</ol>';
    }

    /**
     * Include the TGM_Plugin_Activation class.
     */
    require_once dirname( __FILE__ ) . '/lib/class-tgm-plugin-activation.php';

    add_action( 'tgmpa_register', 'ow_axio_register_required_plugins' );
    /**
     * Register the required plugins for this theme.
     *
     * In this example, we register two plugins - one included with the TGMPA library
     * and one from the .org repo.
     *
     * The variable passed to tgmpa_register_plugins() should be an array of plugin
     * arrays.
     *
     * This function is hooked into tgmpa_init, which is fired within the
     * TGM_Plugin_Activation class constructor.
     */
    function ow_axio_register_required_plugins() {

        /**
         * Array of plugin arrays. Required keys are name and slug.
         * If the source is NOT from the .org repo, then source is also required.
         */
        $plugins = array(

            // This is an example of how to include a plugin from the WordPress Plugin Repository.
            array(
                'name'      => 'Redux Framework',
                'slug'      => 'redux-framework',
                'required'  => true,
            ),

            array(
                'name'      => 'WR PageBuilder',
                'slug'      => 'wr-pagebuilder',
                'required'  => true,
                ),

            array(
                'name'      => 'Contact Form 7',
                'slug'      => 'contact-form-7',
                ),

            );

        /**
         * Array of configuration settings. Amend each line as needed.
         * If you want the default strings to be available under your own theme domain,
         * leave the strings uncommented.
         * Some of the strings are added into a sprintf, so see the comments at the
         * end of each line for what each argument will be.
         */
        $config = array(
            'default_path' => '',                      // Default absolute path to pre-packaged plugins.
            'menu'         => 'tgmpa-install-plugins', // Menu slug.
            'has_notices'  => true,                    // Show admin notices or not.
            'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
            'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
            'is_automatic' => false,                   // Automatically activate plugins after installation or not.
            'message'      => '',                      // Message to output right before the plugins table.
            'strings'      => array(
                'page_title'                      => __( 'Install Required Plugins', 'tgmpa' ),
                'menu_title'                      => __( 'Install Plugins', 'tgmpa' ),
                'installing'                      => __( 'Installing Plugin: %s', 'tgmpa' ), // %s = plugin name.
                'oops'                            => __( 'Something went wrong with the plugin API.', 'tgmpa' ),
                'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s).
                'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s).
                'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s).
                'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
                'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
                'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s).
                'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s).
                'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s).
                'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
                'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins' ),
                'return'                          => __( 'Return to Required Plugins Installer', 'tgmpa' ),
                'plugin_activated'                => __( 'Plugin activated successfully.', 'tgmpa' ),
                'complete'                        => __( 'All plugins installed and activated successfully. %s', 'tgmpa' ), // %s = dashboard link.
                'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
                )
    );

    tgmpa( $plugins, $config );

    }


    // Admin Options (Contact Info) Functions

    function ow_logo_image() {
        global $ow_axio_theme;
        if ($ow_axio_theme['opt-logo-image']['url'] == false) {
            echo '<a href="';
            echo esc_url( site_url() );
            echo '"><h1>';
            echo bloginfo('name');
            echo '</h1></a>';
        } else {
            echo '<a href="';
            echo esc_url( site_url() );
            echo '">';
            echo '<img src="'.$ow_axio_theme['opt-logo-image']['url'].'" alt="Logo" />';
            echo '</a>';
        }
    }

    function ow_favicon() {
        global $ow_axio_theme;
        if (isset($ow_axio_theme['opt-favicon']['url'])) {
            echo '<link rel="icon" href="'.$ow_axio_theme['opt-favicon']['url'].'">';
        } else {
            echo '';
        }
    }

    function ow_contact_info($type) {
        global $ow_axio_theme;
        switch ($type) {
            case 'phone':
            if ($ow_axio_theme['opt-contact-phone'] == false) {
                echo '';
            } else {
                echo '<span><i class="fa fa-phone-square primary-color"></i> <a href="tel:'.$ow_axio_theme['opt-contact-phone'].'">'.$ow_axio_theme['opt-contact-phone'].'</a></span>'; 
            }
            break;

            case 'email':
            if ($ow_axio_theme['opt-contact-email'] == false) {
                echo '';
            } else {
                echo '<span><i class="fa fa-envelope primary-color"></i> <a href="mailto:'.$ow_axio_theme['opt-contact-email'].'">'.$ow_axio_theme['opt-contact-email'].'</a></span>'; 
            }
            break;

            case 'address':
            if ($ow_axio_theme['opt-contact-address'] == false) {
                echo '';
            } else {
                echo '<span><i class="fa fa-map-marker primary-color"></i> '.$ow_axio_theme['opt-contact-address'].'</span>'; 
            }
            break;
        }
    }

    function ow_search_option() {
        global $ow_axio_theme;
        $opt = $ow_axio_theme['opt-search-form'];

        if ($opt == true) { ?>
                <div class="btn-search-nav">
                    <a href="javascript:;" id="link_content-header"><i class="fa fa-search"></i></a>
                </div>
        <?php } else {
            echo '';
        }
    }

    function ow_social_icons($type) {
        global $ow_axio_theme;
        switch ($type) {
            case 'skype':
            if ($ow_axio_theme['opt-social-skype'] == false) {
                echo '';
            } else {
                echo '<li><a href="skype:'.$ow_axio_theme['opt-social-skype'].'?call"><i class="fa fa-skype primary-color"></i></a></li>'; 
            }           
            break;

            case 'facebook':
            if ($ow_axio_theme['opt-social-facebook'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-facebook'].'" target="_blank"><i class="fa fa-facebook primary-color"></i></a></li>'; 
            }           
            break;

            case 'twitter':
            if ($ow_axio_theme['opt-social-twitter'] == false) {
                echo '';
            } else {
                echo '<li><a href="https://twitter.com/'.$ow_axio_theme['opt-social-twitter'].'" target="_blank"><i class="fa fa-twitter primary-color"></i></a></li>'; 
            }           
            break;

            case 'googleplus':
            if ($ow_axio_theme['opt-social-googleplus'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-googleplus'].'" target="_blank"><i class="fa fa-google-plus primary-color"></i></a></li>'; 
            }           
            break;  

            case 'linkedin':
            if ($ow_axio_theme['opt-social-linkedin'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-linkedin'].'" target="_blank"><i class="fa fa-linkedin primary-color"></i></a></li>'; 
            }           
            break;

            case 'youtube':
            if ($ow_axio_theme['opt-social-youtube'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-youtube'].'" target="_blank"><i class="fa fa-youtube-play primary-color"></i></a></li>'; 
            }           
            break;  

            case 'vimeo':
            if ($ow_axio_theme['opt-social-vimeo'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-vimeo'].'" target="_blank"><i class="fa fa-vimeo-square primary-color"></i></a></li>'; 
            }           
            break; 

            case 'pinterest':
            if ($ow_axio_theme['opt-social-pinterest'] == false) {
                echo '';
            } else {
                echo '<li><a href="'.$ow_axio_theme['opt-social-pinterest'].'" target="_blank"><i class="fa fa-pinterest primary-color"></i></a></li>'; 
            }           
            break;
        }

    }

    function ow_social_staff($type) {
        switch ($type) {
            case 'twitter':
                if ($twitter == false) {
                    echo '';
                } else {
                    echo '<div class="col-sm-3 column"><a href="'.$twitter.'"><i class="fa fa-twitter"></i></a></div>';
                }
                break;

            case 'facebook':
                if ($facebook == false) {
                    echo '';
                } else {
                    echo '<div class="col-sm-3 column"><a href="'.$facebook.'"><i class="fa fa-facebook"></i></a></div>';
                }    
                break;

            case 'gplus':
                if ($gplus == false) {
                    echo '';
                } else {
                    echo '<div class="col-sm-3 column"><a href="'.$gplus.'"><i class="fa fa-google-plus"></i></a></div>';
                }
                break;

            case 'linkedin':
                if ($linkedin == false) {
                    echo '';
                } else {
                    echo '<div class="col-sm-3 column"><a href="'.$linkedin.'"><i class="fa fa-linkedin"></i></a></div>';
                }
                break;        
        }
    }
}
add_action( 'after_setup_theme', 'ow_axio_theme_setup' );

?>